==> openshift-model-operatorhub-6.7.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/UpdateStrategyBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UpdateStrategyBuilder extends UpdateStrategyFluentImpl<UpdateStrategyBuilder> implements VisitableBuilder<UpdateStrategy,UpdateStrategyBuilder>{
  public UpdateStrategyBuilder() {
    this(false);
  }
  public UpdateStrategyBuilder(Boolean validationEnabled) {
    this(new UpdateStrategy(), validationEnabled);
  }
  public UpdateStrategyBuilder(UpdateStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public UpdateStrategyBuilder(UpdateStrategyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UpdateStrategy(), validationEnabled);
  }
  public UpdateStrategyBuilder(UpdateStrategyFluent<?> fluent,UpdateStrategy instance) {
    this(fluent, instance, false);
  }
  public UpdateStrategyBuilder(UpdateStrategyFluent<?> fluent,UpdateStrategy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withRegistryPoll(instance.getRegistryPoll());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UpdateStrategyBuilder(UpdateStrategy instance) {
    this(instance,false);
  }
  public UpdateStrategyBuilder(UpdateStrategy instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withRegistryPoll(instance.getRegistryPoll());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UpdateStrategyFluent<?> fluent;
  Boolean validationEnabled;
  public UpdateStrategy build() {
    UpdateStrategy buildable = new UpdateStrategy(fluent.getRegistryPoll());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operatorhub-6.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/UpdateStrategyBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UpdateStrategyBuilder extends UpdateStrategyFluent<UpdateStrategyBuilder> implements VisitableBuilder<UpdateStrategy,UpdateStrategyBuilder>{
  public UpdateStrategyBuilder() {
    this(false);
  }
  public UpdateStrategyBuilder(Boolean validationEnabled) {
    this(new UpdateStrategy(), validationEnabled);
  }
  public UpdateStrategyBuilder(UpdateStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public UpdateStrategyBuilder(UpdateStrategyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UpdateStrategy(), validationEnabled);
  }
  public UpdateStrategyBuilder(UpdateStrategyFluent<?> fluent,UpdateStrategy instance) {
    this(fluent, instance, false);
  }
  public UpdateStrategyBuilder(UpdateStrategyFluent<?> fluent,UpdateStrategy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new UpdateStrategy());

    if (instance != null) {
      fluent.withRegistryPoll(instance.getRegistryPoll());
      fluent.withRegistryPoll(instance.getRegistryPoll());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UpdateStrategyBuilder(UpdateStrategy instance) {
    this(instance,false);
  }
  public UpdateStrategyBuilder(UpdateStrategy instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new UpdateStrategy());

    if (instance != null) {
      this.withRegistryPoll(instance.getRegistryPoll());
      this.withRegistryPoll(instance.getRegistryPoll());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UpdateStrategyFluent<?> fluent;
  Boolean validationEnabled;
  public UpdateStrategy build() {
    UpdateStrategy buildable = new UpdateStrategy(fluent.buildRegistryPoll());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
